@@ -99,7 +99,8 @@
 #include "AudioBufferSource.h"
 #include "AudioReaderSource.h"
 #include "AudioResampler.h"
-#include "Cache.h"
+#include "CacheDisk.h"
+#include "CacheMemory.h"
 #include "ChunkReader.h"
 #include "ChunkWriter.h"
 #include "Clip.h"
